#!/usr/bin/env python

from distutils.core import setup
import os
import glob

name = "python-commandsplus"
version = "0.2.0.9d"

setup(name=name,
	version=version,
	description="A better version of the Python commands module",
	long_description="A Python module with a function that complements the getstatusoutput function in the standard commands module.",
	author="Manuel Amador (Rudd-O)",
	author_email="rudd-o@amautacorp.com",
	url="http://www.amautacorp.com/staff/Rudd-O/",
	py_modules=["commandsplus"],
	)
